<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Añadir complementos</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="102"/>
        <source>Add Widget</source>
        <translation>Añadir widget</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="109"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(Este widget ya se encuentra en el panel)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Configuración del panel</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation>Colocación</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure placement</source>
        <translation>Configurar la ubicación</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation>Dimensiones de los elementos del panel</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Un valor negativo en el tamaño cambia la longitud total del panel restandole esa cantidad al tamaño en la pantalla. &lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Por ejemplo si el &quot;Largo&quot; configurado es -100px, y el tamaño de la pantalla es de 1000px, entonces el largo del panel será de 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Longitud:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Tamaño de los iconos:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation>Filas del panel:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Alineación, posición y características</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Alineación:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation>Posición:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Ocultar el panel a&amp;utomáticamente</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Si elige &quot;0 ms&quot; se desactivarán las animaciones</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Duración de la animación:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Si elige &quot;0 ms&quot; se evitara cualquier retraso</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Retraso antes de aparecer:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>Margen fino visible para el panel oculto</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation>Ocultar solo cuando lo cubra una ventana</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Si se activa esta opción se evitará que las ventanas maximizadas
queden bajo del panel y tengan un area inaccesible</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation>Reservar el espacio del panel en la pantalla</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of desktop</source>
        <translation>Borde superior del escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of desktop</source>
        <translation>Borde izquierdo del escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of desktop</source>
        <translation>Borde derecho del escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of desktop</source>
        <translation>Borde inferior del escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of desktop %1</source>
        <translation>Borde superior del escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of desktop %1</source>
        <translation>Borde izquierdo del escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of desktop %1</source>
        <translation>Borde derecho del escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of desktop %1</source>
        <translation>Borde inferior del escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Configurar los complementos</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Nota: es posible que algunos de los cambios realizados no puedan deshacerse.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Mover hacia arriba</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Mover hacia abajo</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Añadir un widget</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Eliminar un widget</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Abrir la ventana de configuración del widget seleccionado</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation>Configurar el estilo</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation>Personalización del estilo del panel</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation>Color de la fuente:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation>Color del fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation>Opacidad del fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;La composición debe estar activada para usar transparencias en el panel.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation>Imagen de fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>Si tiene problemas para personalizar los widgets que no soportan
usar un tema diferente al original del panel. 

Debe deshabilitar la siguiente casilla:

Configuración de apariencia de LXQt →
Tema de iconos →
Colorear los iconos según la paleta de colores usada en los widgets</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation>Elegir un &amp;tema personalizado para los iconos</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation>Tema de iconos de los paneles:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation>Seleccione un color</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation>Seleccione una imagen</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Imágenes (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1176"/>
        <location filename="../lxqtpanel.cpp" line="1202"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1205"/>
        <source>Configure Panel</source>
        <translation>Configurar este panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1210"/>
        <source>Manage Widgets</source>
        <translation>Gestionar los widgets</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1216"/>
        <source>Add New Panel</source>
        <translation>Añadir otro panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1223"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Eliminar este panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1228"/>
        <source>Lock This Panel</source>
        <translation>Bloquear este panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1384"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Eliminar este panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1385"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Una vez eliminado el panel no puede deshacerse.
¿Seguro que desea borrar este panel?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="438"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Configurar %1</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="443"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Mover %1</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="451"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Eliminar %1</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Utilizar un archivo de configuración alternativo.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Archivo de configuración</translation>
    </message>
</context>
</TS>
